@@ -75,9 +75,9 @@ detector_scope = freephil.parse(
       pixel_mask_applied = False
         .type = bool
         .help = "If the mask location is known, specify whether it's been applied of not."
-      image_size = 4362 4148
+      image_size = 4148 4362
         .type = ints(size = 2)
-        .help = "Image size in pixels: (slow, fast)"
+        .help = "Image size in pixels: (fast, slow)"
       exposure_time = 0.004s
         .type = str
         .help = "Nominal exposure time, if unit is not specified defaults to seconds"
@@ -136,6 +136,9 @@ goniometer_scope = freephil.parse(
       offsets = 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
         .type = floats
         .help = "Axis offsets - one after the other"
+      offset_units = mm mm mm mm mm mm
+        .type = strings
+        .help = "Units of the axis offsets"
       starts = 0.0 0.0 0.0 0.0 0.0 0.0
         .type = floats
         .help = "Starting values for axes"
